# Generated by Django 3.1.5 on 2021-01-08 11:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ci_ynh', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='package',
            name='ci_active',
            field=models.BooleanField(default=True, help_text='Package.ci_active.help_text', verbose_name='Package.ci_active.verbose_name'),
        ),
        migrations.AlterField(
            model_name='check',
            name='status',
            field=models.CharField(blank=True, choices=[('unknown', 'Unknown'), ('running', 'CI is Running'), ('success', 'CI run successful'), ('fail', 'CI run failed'), ('timeout', 'Timeout')], default='unknown', editable=False, help_text='Check.status.help_text', max_length=7, null=True, verbose_name='Check.status.verbose_name'),
        ),
        migrations.AlterField(
            model_name='package',
            name='args',
            field=models.TextField(default='domain=domain.tld\npath=/path\nadmin=johndoe', help_text='Package.args.help_text', verbose_name='Package.args.verbose_name'),
        ),
    ]
